@@ -6,9 +6,9 @@
 # https://github.com/msberends/AMR                                     #
 #                                                                      #
 # PLEASE CITE THIS SOFTWARE AS:                                        #
-# Berends MS, Luz CF, Friedrich AW, Sinha BNM, Albers CJ, Glasner C    #
-# (2022). AMR: An R Package for Working with Antimicrobial Resistance  #
-# Data. Journal of Statistical Software, 104(3), 1-31.                 #
+# Berends MS, Luz CF, Friedrich AW, et al. (2022).                     #
+# AMR: An R Package for Working with Antimicrobial Resistance Data.    #
+# Journal of Statistical Software, 104(3), 1-31.                       #
 # https://doi.org/10.18637/jss.v104.i03                                #
 #                                                                      #
 # Developed at the University of Groningen and the University Medical  #
@@ -24,22 +24,22 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
+# how to conduct AMR data analysis: https://amr-for-r.org              #
 # ==================================================================== #
 
 #' Add Custom Antimicrobials
 #'
 #' With [add_custom_antimicrobials()] you can add your own custom antimicrobial drug names and codes.
-#' @param x a [data.frame] resembling the [antibiotics] data set, at least containing columns "ab" and "name"
+#' @param x A [data.frame] resembling the [antimicrobials] data set, at least containing columns "ab" and "name".
 #' @details **Important:** Due to how \R works, the [add_custom_antimicrobials()] function has to be run in every \R session - added antimicrobials are not stored between sessions and are thus lost when \R is exited.
 #'
 #' There are two ways to circumvent this and automate the process of adding antimicrobials:
 #'
-#' **Method 1:** Using the [package option][AMR-options] [`AMR_custom_ab`][AMR-options], which is the preferred method. To use this method:
+#' **Method 1:** Using the package option [`AMR_custom_ab`][AMR-options], which is the preferred method. To use this method:
 #'
-#'    1. Create a data set in the structure of the [antibiotics] data set (containing at the very least columns "ab" and "name") and save it with [saveRDS()] to a location of choice, e.g. `"~/my_custom_ab.rds"`, or any remote location.
+#'    1. Create a data set in the structure of the [antimicrobials] data set (containing at the very least columns "ab" and "name") and save it with [saveRDS()] to a location of choice, e.g. `"~/my_custom_ab.rds"`, or any remote location.
 #'
-#'    2. Set the file location to the [package option][AMR-options] [`AMR_custom_ab`][AMR-options]: `options(AMR_custom_ab = "~/my_custom_ab.rds")`. This can even be a remote file location, such as an https URL. Since options are not saved between \R sessions, it is best to save this option to the `.Rprofile` file so that it will be loaded on start-up of \R. To do this, open the `.Rprofile` file using e.g. `utils::file.edit("~/.Rprofile")`, add this text and save the file:
+#'    2. Set the file location to the package option [`AMR_custom_ab`][AMR-options]: `options(AMR_custom_ab = "~/my_custom_ab.rds")`. This can even be a remote file location, such as an https URL. Since options are not saved between \R sessions, it is best to save this option to the `.Rprofile` file so that it will be loaded on start-up of \R. To do this, open the `.Rprofile` file using e.g. `utils::file.edit("~/.Rprofile")`, add this text and save the file:
 #'
 #'       ```r
 #'       # Add custom antimicrobial codes:
@@ -69,11 +69,8 @@
 #' @export
 #' @examples
 #' \donttest{
-#'
-#' # returns NA and throws a warning (which is suppressed here):
-#' suppressWarnings(
-#'   as.ab("testab")
-#' )
+#' # returns a wildly guessed result:
+#' as.ab("testab")
 #'
 #' # now add a custom entry - it will be considered by as.ab() and
 #' # all ab_*() functions
@@ -82,7 +79,7 @@
 #'     ab = "TESTAB",
 #'     name = "Test Antibiotic",
 #'     # you can add any property present in the
-#'     # 'antibiotics' data set, such as 'group':
+#'     # 'antimicrobials' data set, such as 'group':
 #'     group = "Test Group"
 #'   )
 #' )
@@ -96,7 +93,7 @@
 #'
 #'
 #' # Add Co-fluampicil, which is one of the many J01CR50 codes, see
-#' # https://www.whocc.no/ddd/list_of_ddds_combined_products/
+#' # https://atcddd.fhi.no/ddd/list_of_ddds_combined_products/
 #' add_custom_antimicrobials(
 #'   data.frame(
 #'     ab = "COFLU",
@@ -108,7 +105,8 @@
 #' ab_atc("Co-fluampicil")
 #' ab_name("J01CR50")
 #'
-#' # even antibiotic selectors work
+#' # even antimicrobial selectors work
+#' # see ?amr_selector
 #' x <- data.frame(
 #'   random_column = "some value",
 #'   coflu = as.sir("S"),
@@ -125,11 +123,11 @@ add_custom_antimicrobials <- function(x) {
   )
   stop_if(
     any(x$ab %in% AMR_env$AB_lookup$ab),
-    "Antimicrobial drug code(s) ", vector_and(x$ab[x$ab %in% AMR_env$AB_lookup$ab]), " already exist in the internal `antibiotics` data set."
+    "Antimicrobial drug code(s) ", vector_and(x$ab[x$ab %in% AMR_env$AB_lookup$ab]), " already exist in the internal `antimicrobials` data set."
   )
   # remove any extra class/type, such as grouped tbl, or data.table:
   x <- as.data.frame(x, stringsAsFactors = FALSE)
-  # keep only columns available in the antibiotics data set
+  # keep only columns available in the antimicrobials data set
   x <- x[, colnames(AMR_env$AB_lookup)[colnames(AMR_env$AB_lookup) %in% colnames(x)], drop = FALSE]
   x$generalised_name <- generalise_antibiotic_name(x$name)
   x$generalised_all <- as.list(x$generalised_name)
@@ -155,18 +153,18 @@ add_custom_antimicrobials <- function(x) {
   }
   AMR_env$AB_lookup <- unique(rbind_AMR(AMR_env$AB_lookup, new_df))
 
-  AMR_env$ab_previously_coerced <- AMR_env$ab_previously_coerced[which(!AMR_env$ab_previously_coerced$ab %in% x$ab), , drop = FALSE]
+  AMR_env$ab_previously_coerced <- AMR_env$ab_previously_coerced[which(!AMR_env$ab_previously_coerced$ab %in% c(x$ab, x$generalised_name) & !AMR_env$ab_previously_coerced$x %in% c(x$ab, x$generalised_name)), , drop = FALSE]
   class(AMR_env$AB_lookup$ab) <- c("ab", "character")
-  message_("Added ", nr2char(nrow(x)), " record", ifelse(nrow(x) > 1, "s", ""), " to the internal `antibiotics` data set.")
+  message_("Added ", nr2char(nrow(x)), " record", ifelse(nrow(x) > 1, "s", ""), " to the internal `antimicrobials` data set.")
 }
 
 #' @rdname add_custom_antimicrobials
 #' @export
 clear_custom_antimicrobials <- function() {
   n <- nrow(AMR_env$AB_lookup)
-  AMR_env$AB_lookup <- cbind(AMR::antibiotics, AB_LOOKUP)
+  AMR_env$AB_lookup <- cbind(AMR::antimicrobials, AB_LOOKUP)
   n2 <- nrow(AMR_env$AB_lookup)
   AMR_env$custom_ab_codes <- character(0)
   AMR_env$ab_previously_coerced <- AMR_env$ab_previously_coerced[which(AMR_env$ab_previously_coerced$ab %in% AMR_env$AB_lookup$ab), , drop = FALSE]
-  message_("Cleared ", nr2char(n - n2), " custom record", ifelse(n - n2 > 1, "s", ""), " from the internal `antibiotics` data set.")
+  message_("Cleared ", nr2char(n - n2), " custom record", ifelse(n - n2 > 1, "s", ""), " from the internal `antimicrobials` data set.")
 }
