@@ -1,15 +1,19 @@
 # ==================================================================== #
-# TITLE                                                                #
-# Antimicrobial Resistance (AMR) Data Analysis for R                   #
+# TITLE:                                                               #
+# AMR: An R Package for Working with Antimicrobial Resistance Data     #
 #                                                                      #
-# SOURCE                                                               #
+# SOURCE CODE:                                                         #
 # https://github.com/msberends/AMR                                     #
 #                                                                      #
-# LICENCE                                                              #
-# (c) 2018-2021 Berends MS, Luz CF et al.                              #
-# Developed at the University of Groningen, the Netherlands, in        #
-# collaboration with non-profit organisations Certe Medical            #
-# Diagnostics & Advice, and University Medical Center Groningen.       # 
+# PLEASE CITE THIS SOFTWARE AS:                                        #
+# Berends MS, Luz CF, Friedrich AW, et al. (2022).                     #
+# AMR: An R Package for Working with Antimicrobial Resistance Data.    #
+# Journal of Statistical Software, 104(3), 1-31.                       #
+# https://doi.org/10.18637/jss.v104.i03                                #
+#                                                                      #
+# Developed at the University of Groningen and the University Medical  #
+# Center Groningen in The Netherlands, in collaboration with many      #
+# colleagues from around the world, see our website.                   #
 #                                                                      #
 # This R package is free software; you can freely use and distribute   #
 # it for both personal and commercial purposes under the terms of the  #
@@ -20,20 +24,19 @@
 # useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 #                                                                      #
 # Visit our website for the full manual and a complete tutorial about  #
-# how to conduct AMR data analysis: https://msberends.github.io/AMR/   #
+# how to conduct AMR data analysis: https://amr-for-r.org              #
 # ==================================================================== #
 
-context("join_microorganisms.R")
-
-test_that("joins work", {
+test_that("test-join_microorganisms.R", {
   skip_on_cran()
+
   unjoined <- example_isolates
-  inner <- example_isolates %>% inner_join_microorganisms()
-  left <- example_isolates %>% left_join_microorganisms()
-  semi <- example_isolates %>% semi_join_microorganisms()
-  anti <- example_isolates %>% anti_join_microorganisms()
-  suppressWarnings(right <- example_isolates %>% right_join_microorganisms())
-  suppressWarnings(full <- example_isolates %>% full_join_microorganisms())
+  inner <- inner_join_microorganisms(example_isolates)
+  left <- left_join_microorganisms(example_isolates)
+  semi <- semi_join_microorganisms(example_isolates)
+  anti <- anti_join_microorganisms(example_isolates)
+  suppressWarnings(right <- right_join_microorganisms(example_isolates))
+  suppressWarnings(full <- full_join_microorganisms(example_isolates))
 
   expect_true(ncol(unjoined) < ncol(inner))
   expect_true(nrow(unjoined) == nrow(inner))
@@ -57,11 +60,6 @@ test_that("joins work", {
   expect_equal(nrow(semi_join_microorganisms("B_ESCHR_COLI")), 1)
   expect_equal(nrow(anti_join_microorganisms("B_ESCHR_COLI")), 0)
 
-  expect_warning(right_join_microorganisms("B_ESCHR_COLI"))
-  expect_warning(full_join_microorganisms("B_ESCHR_COLI"))
-  
-  library(dplyr, warn.conflicts = FALSE)
-  x <- tibble(bact = as.mo("E.coli"))
-  expect_warning(left_join_microorganisms(x %>% group_by(bact), "bact"))
-
+  # expect_warning(right_join_microorganisms("B_ESCHR_COLI"))
+  # expect_warning(full_join_microorganisms("B_ESCHR_COLI"))
 })
